@@ -3,7 +3,7 @@ package WWW::Contact::Yahoo;
 use Moose;
 extends 'WWW::Contact::Base';
 
-our $VERSION   = '0.33';
+our $VERSION   = '0.34';
 our $AUTHORITY = 'cpan:FAYLAND';
 
 has '+ua_class' => ( default => 'WWW::Mechanize::GZip' );
@@ -33,6 +33,12 @@ sub get_contacts {
         return;
     }
     
+    # https://edit.yahoo.com/recovery/update
+    if ( $ua->base =~ /recovery\/update/ ) {
+        $self->errstr("Account Recovery Issue");
+        return;
+    }
+    
     $self->debug('Login OK');
 
     $self->get('http://address.mail.yahoo.com/?_src=&VPC=tools_print') || return;
